<?php defined('SYSPATH') or die('No direct script access.');

// -- Environment setup --------------------------------------------------------

// Load the core Kohana class
require SYSPATH.'classes/kohana/core'.EXT;

if (is_file(APPPATH.'classes/kohana'.EXT))
{
	// Application extends the core
	require APPPATH.'classes/kohana'.EXT;
}
else
{
	// Load empty core extension
	require SYSPATH.'classes/kohana'.EXT;
}

/**
 * Set the default time zone.
 *
 * @see  http://kohanaframework.org/guide/using.configuration
 * @see  http://php.net/timezones
 */
date_default_timezone_set('America/New_York');
/**
 * Set the default locale.
 *
 * @see  http://kohanaframework.org/guide/using.configuration
 * @see  http://php.net/setlocale
 */
setlocale(LC_ALL, 'en_US.utf-8');

/**
 * Enable the Kohana auto-loader.
 *
 * @see  http://kohanaframework.org/guide/using.autoloading
 * @see  http://php.net/spl_autoload_register
 */
spl_autoload_register(array('Kohana', 'auto_load'));

/**
 * Enable the Kohana auto-loader for unserialization.
 *
 * @see  http://php.net/spl_autoload_call
 * @see  http://php.net/manual/var.configuration.php#unserialize-callback-func
 */
ini_set('unserialize_callback_func', 'spl_autoload_call');

// -- Configuration and initialization -----------------------------------------

/**
 * Set the default language
 */
I18n::lang('en-us');

/**
 * Set Kohana::$environment if a 'KOHANA_ENV' environment variable has been supplied.
 *
 * Note: If you supply an invalid environment name, a PHP warning will be thrown
 * saying "Couldn't find constant Kohana::<INVALID_ENV_NAME>"
 */
if (isset($_SERVER['KOHANA_ENV']))
{
	Kohana::$environment = constant('Kohana::'.strtoupper($_SERVER['KOHANA_ENV']));
}
else if (isset($_SERVER['SERVER_ADDR']))
{
	Kohana::$environment = ($_SERVER['SERVER_ADDR'] === '127.0.0.1')
	                     ? Kohana::DEVELOPMENT
	                     : Kohana::PRODUCTION;
}
else
{
	Kohana::$environment = Kohana::PRODUCTION;
}

/**
 * Initialize Kohana, setting the default options.
 *
 * The following options are available:
 *
 * - string   base_url    path, and optionally domain, of your application   NULL
 * - string   index_file  name of your index file, usually "index.php"       index.php
 * - string   charset     internal character set used for input and output   utf-8
 * - string   cache_dir   set the internal cache directory                   APPPATH/cache
 * - boolean  errors      enable or disable error handling                   TRUE
 * - boolean  profile     enable or disable internal profiling               TRUE
 * - boolean  caching     enable or disable internal caching                 FALSE
 */
Kohana::init(array(
	'base_url'   => (Kohana::$environment === Kohana::PRODUCTION)
	             ?  'http://park-a-lot.vacau.com/'
	             :  'http://park-a-lot.localhost/',
	'index_file' => FALSE,
	'profile'    => (Kohana::$environment !== Kohana::PRODUCTION),
	'caching'    => (Kohana::$environment === Kohana::PRODUCTION),
));

/**
 * Attach the file write to logging. Multiple writers are supported.
 */
Kohana::$log->attach(new Log_File(APPPATH.'logs'));

/**
 * Attach a file reader to config. Multiple readers are supported.
 */
Kohana::$config->attach(new Config_File);

// Loaded in any environment
$modules = array(
	'auth'     => MODPATH.'auth',
	'database' => MODPATH.'database',
	'email'    => MODPATH.'email',
	'image'    => MODPATH.'image',
	'kostache' => MODPATH.'kostache',
	'orm'      => MODPATH.'orm',
);

// Environment specific modules
switch (Kohana::$environment)
{
	case Kohana::DEVELOPMENT;
		$modules += array(
			'codebench' => MODPATH.'codebench',
			'userguide' => MODPATH.'userguide',
		);
	break;

	case Kohana::PRODUCTION:
		$modules += array(
			'cache' => MODPATH.'cache',
		);
	break;

	case Kohana::TESTING:
		$modules += array(
			'unittest' => MODPATH.'unittest',
		);
	break;
}

Kohana::modules($modules);
unset($modules);

/**
 * Set the routes. Each route must have a minimum of a name, a URI and a set of
 * defaults for the URI.
 */
if ( ! Route::cache())
{
	if (Kohana::$environment === Kohana::STAGING)
	{
		// Route everything to show an "under maintenance" message
		Route::set('everything', '(<everything>)', array('everything' => '.*'))
			->defaults(array(
				'controller' => 'static',
				'action'     => 'maintenance',
			));
	}

	Route::set('error', 'error/<action>', array('action' => '[0-9]++'))
		->defaults(array(
			'controller' => 'error',
			'action'     => 404,
		));

	Route::set('user_profile', 'profile')
		->defaults(array(
			'controller' => 'user',
			'action'     => 'profile',
		));

	Route::set('login', 'login')
		->defaults(array(
			'controller' => 'user',
			'action'     => 'login',
		));

	Route::set('admin', 'admin(/<controller>(/<action>(/<id>)))')
		->defaults(array(
			'directory'  => 'admin',
			'controller' => 'garage',
			'action'     => 'usage',
		));

	Route::set('default', '(<controller>(/<action>(/<id>)))')
		->defaults(array(
			'controller' => 'home',
			'action'     => 'index',
		));
	
	Route::cache(Kohana::$environment === Kohana::PRODUCTION);
}